@@ -216,6 +216,9 @@ CCanvas::CCanvas()
 
     largeIcons = cfg.value("environment/largeIcons", largeIcons).toBool();
     qApp->installEventFilter(this);
+
+    //setAttribute(Qt::WA_Maemo5AutoOrientation, true);
+    //connect(QApplication::desktop(), SIGNAL(resized(int)), this, SLOT(orientationChanged()));
 }
 
 
@@ -402,23 +405,23 @@ void CCanvas::slotKey2()
     CMenu menu(this);
 
     if(cursorMode == eUser){
-        menu.addAction(1,tr("gps"), QIcon(":/icons/gps64x64"), this, SLOT(leaveUserMode()));
+        menu.addAction(1,tr("gps"), QIcon(":/icons/gps64x64.png"), this, SLOT(leaveUserMode()));
     }
 
     if (CTrackDB::self().getState() == CTrackDB::ePause) {
-        menu.addAction(7,tr("pause"), QIcon(":/icons/pause32x32"), &CTrackDB::self(), SLOT(pause()));
-        menu.addAction(8,tr("stop"), QIcon(":/icons/stop32x32"), &CTrackDB::self(), SLOT(stop()));
+        menu.addAction(7,tr("pause"), QIcon(":/icons/pause32x32.png"), &CTrackDB::self(), SLOT(pause()));
+        menu.addAction(8,tr("stop"), QIcon(":/icons/stop32x32.png"), &CTrackDB::self(), SLOT(stop()));
     }
     else if (CTrackDB::self().getState() == CTrackDB::eRecord) {
-        menu.addAction(7,tr("pause"), QIcon(":/icons/pause32x32"), &CTrackDB::self(), SLOT(pause()));
-        menu.addAction(8,tr("stop"), QIcon(":/icons/stop32x32"), &CTrackDB::self(), SLOT(stop()));
+        menu.addAction(7,tr("pause"), QIcon(":/icons/pause32x32.png"), &CTrackDB::self(), SLOT(pause()));
+        menu.addAction(8,tr("stop"), QIcon(":/icons/stop32x32.png"), &CTrackDB::self(), SLOT(stop()));
     }
     else {
-        menu.addAction(7,tr("rec."), QIcon(":/icons/record32x32"), &CTrackDB::self(), SLOT(record()));
+        menu.addAction(7,tr("rec."), QIcon(":/icons/record32x32.png"), &CTrackDB::self(), SLOT(record()));
     }
 
-    menu.addAction(5,tr("waypoint"), QIcon(":/icons/waypoint64x64"), &CWptDB::self(), SLOT(addWptToPos()));
-    menu.addAction(4, tr("back"), QIcon(":/icons/back64x64"));
+    menu.addAction(5,tr("waypoint"), QIcon(":/icons/waypoint64x64.png"), &CWptDB::self(), SLOT(addWptToPos()));
+    menu.addAction(4, tr("back"), QIcon(":/icons/back64x64.png"));
 
     int y = infoScreen->height();
     int x = (width() - menu.width()) >> 1;
@@ -486,15 +489,15 @@ void CCanvas::slotNewGpsData(IGps& gps)
     if(largeIcons){
         switch(CTrackDB::self().getState()){
             case CTrackDB::eRecord:
-                labelTrackStatus->setPixmap(QPixmap(":/icons/record32x32"));
+                labelTrackStatus->setPixmap(QPixmap(":/icons/record32x32.png"));
                 break;
 
             case CTrackDB::ePause:
-                labelTrackStatus->setPixmap(QPixmap(":/icons/pause32x32"));
+                labelTrackStatus->setPixmap(QPixmap(":/icons/pause32x32.png"));
                 break;
 
             case CTrackDB::eStop:
-                labelTrackStatus->setPixmap(QPixmap(":/icons/stop32x32"));
+                labelTrackStatus->setPixmap(QPixmap(":/icons/stop32x32.png"));
                 break;
 
         }
@@ -502,15 +505,15 @@ void CCanvas::slotNewGpsData(IGps& gps)
     else{
         switch(CTrackDB::self().getState()){
             case CTrackDB::eRecord:
-                labelTrackStatus->setPixmap(QPixmap(":/icons/record16x16"));
+                labelTrackStatus->setPixmap(QPixmap(":/icons/record16x16.png"));
                 break;
 
             case CTrackDB::ePause:
-                labelTrackStatus->setPixmap(QPixmap(":/icons/pause16x16"));
+                labelTrackStatus->setPixmap(QPixmap(":/icons/pause16x16.png"));
                 break;
 
             case CTrackDB::eStop:
-                labelTrackStatus->setPixmap(QPixmap(":/icons/stop16x16"));
+                labelTrackStatus->setPixmap(QPixmap(":/icons/stop16x16.png"));
                 break;
 
         }
