@@ -29,6 +29,7 @@
 #include <QtGui>
 #include <QSqlQuery>
 #include <QSqlError>
+#include <QGeoCoordinate>
 #include <projects.h>
 
 CWptDB * CWptDB::m_self = 0;
@@ -59,8 +60,6 @@ CWptDB::CWptDB(QObject * parent)
         dir.mkdir("MyPOI");
     }
 
-
-
 }
 
 
@@ -149,7 +148,7 @@ void CWptDB::draw(QPainter& p, const QRectF& viewport)
     qreal lat2 = viewport.bottom() * RAD_TO_DEG;
 
     QSqlQuery query(db);
-    query.prepare("SELECT lon, lat, icon, name FROM waypoint WHERE :lon1 < lon AND lon < :lon2 AND :lat1 < lat AND lat < :lat2");
+    query.prepare("SELECT lon, lat, icon, name, prx FROM waypoint WHERE :lon1 < lon AND lon < :lon2 AND :lat1 < lat AND lat < :lat2");
     query.bindValue(":lon1", lon1);
     query.bindValue(":lat1", lat1);
     query.bindValue(":lon2", lon2);
@@ -163,6 +162,14 @@ void CWptDB::draw(QPainter& p, const QRectF& viewport)
     while(query.next()){
         qreal x         = query.value(0).toDouble() * DEG_TO_RAD;
         qreal y         = query.value(1).toDouble() * DEG_TO_RAD;
+
+        QGeoCoordinate wptLocation(query.value(0).toDouble(), query.value(1).toDouble());
+        monitor = QGeoAreaMonitor::createDefaultMonitor(this);
+        monitor->setCenter( wptLocation);
+        monitor->setRadius( query.value(4).toDouble() );
+        connect(monitor, SIGNAL(areaEntered(QGeoPositionInfo)),
+                            this, SLOT(areaEntered(QGeoPositionInfo)));
+
         QString icon    = query.value(2).toString();
         QString name    = query.value(3).toString();
 
@@ -469,3 +476,8 @@ bool  CWptDB::getUsedIcons(QSet<QString>& icons, QString& errmsg)
 
     return true;
 }
+
+void CWptDB::areaEntered(const QGeoPositionInfo &update)
+{
+    qDebug() << "Waypoint proximity " << update.coordinate().toString();
+}
